@@ -48,16 +48,25 @@ class Parser:
         for pos in cte_main.finditer(query):
             pos_list_main.append(pos.start())
            
-        
         if pos_list != []:
             cte_dict = {}
-            for _, pos in enumerate(pos_list):
-                if pos < len(pos_list)-1:
-                    cte_query = query[pos:]
+            for index, pos in enumerate(pos_list):
+                if index < len(pos_list)-1:
+                    cte_query = query[pos:pos_list[index+1]]
                 else:
                     cte_query = query[pos:pos_list_main[-1]]
+
+                cte_query = cte_query.rstrip('\n,')
+                cte_query = re.sub(r"\)$", "", cte_query)
+
                 cte_name = re.findall(r"(WITH)*(.*)AS", cte_query)[0][1].strip(' ')    
-                cte_dict[cte_name] = cte_query
+                cte_removed = re.compile(r"\(SELECT")
+                pos_list_removed = []
+
+                for pos in cte_removed.finditer(cte_query):
+                    pos_list_removed.append(pos.start())
+                    
+                cte_dict[cte_name] = cte_query[pos_list_removed[0]+1:]
 
             cte_dict['main'] = query[pos_list_main[-1]:]
             
@@ -97,10 +106,16 @@ class Parser:
                 
                 if len(table_name_line) == 1:
                     table_name_mapping[table_name_line[0].rstrip(')|,')] = table_name_line[0].rstrip(')|,')
-                    
-                elif len(table_name_line) > 1:
+
+                if len(table_name_line) == 2:
                     table_name_mapping[table_name_line[-1].rstrip(')|,')] = table_name_line[0].rstrip(')|,')
 
+                elif len(table_name_line) > 2 and table_name_line[1] == 'AS':
+                    table_name_mapping[table_name_line[2].rstrip(')|,')] = table_name_line[0].rstrip(')|,')
+                
+                elif len(table_name_line) > 2 and table_name_line[1] != 'AS':
+                    table_name_mapping[table_name_line[1].rstrip(')|,')] = table_name_line[0].rstrip(')|,')
+
         return table_name_mapping
 
 
@@ -115,10 +130,12 @@ class Parser:
         all_variables = []
 
         for e in query.split('\n'):
-            if sum(list(map(lambda x: '*' in x, re.findall(r"\s[*]?", query)))):
-                variable = []
+            if sum(list(map(lambda x: '*' in x, re.findall(r"([a-z].*[*])", e)))):
+                variable = re.findall(r"([a-z].*[*])", e)
+            elif sum(list(map(lambda x: '*' in x, re.findall(r"([*])", e)))):
+                variable = re.findall(r"([*])", e)
             else:
-                variable = re.findall(r"[a-z_\s.]+", e.lstrip(' '))
+                variable = [x.strip(' ') for x in re.findall(r"[a-z_\s.]+", e)]
 
             all_variables.extend(variable)
 
@@ -167,20 +184,31 @@ class Parser:
                 var_split = var.split('.')
             
                 if len(var_split) == 1:
-                    for db_table in queried_cols:
-                        for k,v in db_table.items():
-                            if var in v:
-                                original_columns_list.append("{}.{}".format(k, var))
+                    if var_split[0] == '*':
+                        for db_table in queried_cols:
+                            for k,v in db_table.items():
+                                for col in v:
+                                    original_columns_list.append("{}.{}".format(k, col))
+                        
+                    else:
+                        for db_table in queried_cols:
+                            for k,v in db_table.items():
+                                if var in v:
+                                    original_columns_list.append("{}.{}".format(k, var))
 
                 elif len(var_split) == 2:
 
                     if var_split[0] in table_alias_mapping.keys():
                         db_table = table_alias_mapping[var_split[0]]
-
+                    
                         for db_table_col in queried_cols:
                             for k,v in db_table_col.items():
+
                                 if k == db_table and var_split[1] in v:
                                     original_columns_list.append("{}.{}".format(k, var_split[1]))
+                                elif k == db_table and var_split[1] == '*':
+                                    for col in v:
+                                        original_columns_list.append("{}.{}".format(k, col))     
 
         return list(set(original_columns_list))
             
@@ -251,16 +279,3 @@ class Parser:
                 pass
 
         return column_payload
-
-
-# def main(query_location, run_date):
-
-#     logging.info('Getting all fields since last snapshot...')
-#     db_fields = get_db_fields(s3, run_date)
-
-#     logging.info('Reading query...')
-#     query = open('query.sql').read()
-#     formatter = Parser(query)
-#     columns_queried = formatter.match_queried_fields(query, db_fields)
-
-#     return columns_queried
